==> haskell-githash-0.1.6.3-320-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-githash.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 githash
version:              0.1.6.3
visibility:           public
id:                   githash-0.1.6.3-2yW9KwVpOZo9zEtht9Hsdo
key:                  githash-0.1.6.3-2yW9KwVpOZo9zEtht9Hsdo
license:              BSD-3-Clause
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Adam C. Foltzer
homepage:             https://github.com/snoyberg/githash#readme
synopsis:             Compile git revision info into Haskell projects
description:
    Please see the README and documentation at <https://www.stackage.org/package/githash>

category:             Development
abi:                  37f6ab204803dbfb9a2e97544e821dc2
exposed:              True
exposed-modules:      GitHash
hidden-modules:       Paths_githash
import-dirs:          /usr/lib/ghc-9.4.8/site-local/githash-0.1.6.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/githash-0.1.6.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/githash-0.1.6.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-githash
hs-libraries:         HSgithash-0.1.6.3-2yW9KwVpOZo9zEtht9Hsdo
depends:
    base-4.17.2.1 bytestring-0.11.5.3 directory-1.3.7.1
    filepath-1.4.2.2 process-1.6.18.0 template-haskell-2.19.0.0
    th-compat-0.1.6-3T4uoPly2m55QZYohviMel

haddock-interfaces:   /usr/share/doc/haskell-githash/html/githash.haddock
haddock-html:         /usr/share/doc/haskell-githash/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-githash-0.1.6.3-321-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-githash.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 githash
version:              0.1.6.3
visibility:           public
id:                   githash-0.1.6.3-HPhO0WJvBOV198BThwzxQo
key:                  githash-0.1.6.3-HPhO0WJvBOV198BThwzxQo
license:              BSD-3-Clause
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Adam C. Foltzer
homepage:             https://github.com/snoyberg/githash#readme
synopsis:             Compile git revision info into Haskell projects
description:
    Please see the README and documentation at <https://www.stackage.org/package/githash>

category:             Development
abi:                  6fe32ce66fac1875a3baef4293838709
exposed:              True
exposed-modules:      GitHash
hidden-modules:       Paths_githash
import-dirs:          /usr/lib/ghc-9.4.8/site-local/githash-0.1.6.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/githash-0.1.6.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/githash-0.1.6.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-githash
hs-libraries:         HSgithash-0.1.6.3-HPhO0WJvBOV198BThwzxQo
depends:
    base-4.17.2.1 bytestring-0.11.5.3 directory-1.3.7.1
    filepath-1.4.2.2 process-1.6.18.0 template-haskell-2.19.0.0
    th-compat-0.1.6-DEXh5ZHqAmADAuxbkzibMp

haddock-interfaces:   /usr/share/doc/haskell-githash/html/githash.haddock
haddock-html:         /usr/share/doc/haskell-githash/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
